# -*- coding: utf-8 -*-
from cubicweb.devtools.testlib import CubicWebTC
from cubicweb.web import uicfg
from cubicweb.web.views import actions, embedding
from cubes.link import views

afs = uicfg.autoform_section

class LinkTC(CubicWebTC):

    def setup_database(self):
        self.request().create_entity('Link', title=u"vous êtes perdu ?", url=u"http://www.perdu.com")

    def test_possible_actions(self):
        req = self.request()
        rset = self.execute('Any X WHERE X is Link')
        self.assertEquals(self.pactionsdict(req, rset),
                             {'moreactions': [embedding.EmbedAction],
                              'mainactions': [actions.ModifyAction, views.LinkFollowAction],
                              'moreactions': [actions.ManagePermissionsAction, actions.AddRelatedActions,
                                              actions.DeleteAction, actions.CopyAction,
                                              embedding.EmbedAction],
                              })

    def test_relations_by_category(self):
        def rbc(iterable):
            return [(rschema.type, x) for rschema, tschemas, x in iterable]
        e = self.vreg["etypes"].etype_class('Link')(self.request())
        # we should only see embed when we are in the managers group
        self.assertEquals(rbc(afs.relations_by_section(e, 'main', 'attributes', 'add')),
                          [('title', 'subject'), ('url', 'subject'),
                           ('embed', 'subject'),
                           ('description', 'subject'),
                           ('eid', 'subject')])
        self.assertEquals(rbc(afs.relations_by_section(e,'main', 'attributes', 'delete')),
                          [('title', 'subject'), ('url', 'subject'),
                           ('embed', 'subject'),
                           ('description', 'subject'),
                           ('eid', 'subject')])
        self.create_user('toto')
        self.login('toto')
        # create a new instance with the new connection
        e = self.vreg["etypes"].etype_class('Link')(self.request())
        self.assertEquals(rbc(afs.relations_by_section(e, 'main', 'attributes', 'add')),
                          [('title', 'subject'), ('url', 'subject'),
                           ('description', 'subject'),
                           ('eid', 'subject')])
        self.assertEquals(rbc(afs.relations_by_section(e, 'main', 'attributes', 'delete')),
                          [('title', 'subject'), ('url', 'subject'),
                           ('description', 'subject'),
                           ('eid', 'subject')])

if __name__ == '__main__':
    from logilab.common.testlib import unittest_main
    unittest_main()
